Name:           veusz
Version:        1.26.1
Release:        %mkrel 1
Summary:        GUI scientific plotting package

Group:          Sciences/Mathematics
# The entire source code is GPLv2+ except helpers/src/_nc_cntr.c which is Python
License:        GPLv2+ and Python
URL:            https://veusz.github.io/download/
Source0:        https://veusz.github.io/download/%{name}-%{version}.tar.gz

BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python-numpy-devel
BuildRequires:  python-qt4
BuildRequires:  python-sip
BuildRequires:  qt4-devel
BuildRequires:  sip-devel

BuildRequires:  x11-server-xvfb
BuildRequires:  xauth
# below is necessary for the test to work
BuildRequires:  urw-fonts

Requires:       python-astropy >= 0.2.3
Requires:       python-sampy

%{?_sip_api:Requires: sip-api(%{_sip_api_major}) >= %{_sip_api}}
Requires:       python-numpy
Requires:       python-qt4
Requires:       /usr/bin/env
Provides:       python-veusz = %{version}

# we don't want to provide private python extension libs
%{?filter_setup:
%filter_provides_in %{python2_sitearch}/veusz/helpers/.*\.so$
%filter_setup
}

%description
Veusz is a scientific plotting package, designed to create
publication-ready Postscript/PDF/SVG output. It features GUI,
command-line, and scripting interfaces. Graphs are constructed from
widgets, allowing complex layouts to be designed. Veusz supports
plotting functions, data with error bars, keys, labels, stacked plots,
ternary plots, vector plots, contours, images, shapes and fitting
data.

%prep
%setup -q -n veusz-%{version}
%autopatch -p1

find -name \*~ | xargs rm -f

%build
%py2_build

%install
# veusz-resource-dir: put data files in location given
%define install_parameters --veusz-resource-dir=%{buildroot}%{_datadir}/veusz --disable-install-examples
%py2_install %install_parameters

# tell veusz where its resource directory is in _datadir
ln -s %{_datadir}/veusz \
    %{buildroot}%{python2_sitearch}/veusz/resources

# tell it where to look for examples
ln -s  %{_defaultdocdir}/%{name}/examples \
    %{buildroot}%{_datadir}/veusz

# install desktop file
desktop-file-install  \
    --dir %{buildroot}%{_datadir}/applications \
    support/veusz.desktop

# file to register .vsz mimetype
mkdir -p %{buildroot}%{_datadir}/mime/packages/
install -p support/veusz.xml -m 0644 %{buildroot}%{_datadir}/mime/packages/

# appdata file
mkdir -p %{buildroot}%{_datadir}/appdata/
install -p support/veusz.appdata.xml -m 0644 %{buildroot}%{_datadir}/appdata/

# symlink main veusz icon into pixmaps (for desktop file)
mkdir %{buildroot}%{_datadir}/pixmaps
ln -s ../veusz/icons/veusz_48.png %{buildroot}%{_datadir}/pixmaps/veusz.png

# also link in hicolor icons
for size in 16 32 48 64 128; do
    odir=%{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps
    mkdir -p $odir
    ln -s %{_datadir}/veusz/icons/veusz_${size}.png ${odir}/veusz.png
done
odir=%{buildroot}%{_datadir}/icons/hicolor/scalable/apps
mkdir -p $odir
ln -s %{_datadir}/veusz/icons/veusz.svg $odir

# install man pages
mkdir -p %{buildroot}%{_mandir}/man1
install -p Documents/veusz.1 Documents/veusz_listen.1 -m 0644 \
    %{buildroot}%{_mandir}/man1

%check
%define enable_tests 0
%if %{enable_tests}
# self test has to run in X environment
# as the data directory hasn't got the same absolute path we have
# to define VEUSZ_RESOURCE_DIR
PYTHONPATH=%{buildroot}%{python2_sitearch} \
    VEUSZ_RESOURCE_DIR=%{buildroot}%{_datadir}/veusz \
    xvfb-run \
    --auto-servernum \
    --server-args "-screen 0 640x480x24" \
    %{__python} tests/runselftest.py
%endif

%files
%doc README AUTHORS COPYING
%doc examples
%doc Documents/manual.html
%doc Documents/manimages
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/applications/*
%{_datadir}/mime/packages/*
%{_datadir}/appdata/*
%{_datadir}/pixmaps/*
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/veusz/
%{python2_sitearch}/veusz-*.egg-info
%{python2_sitearch}/veusz


%changelog
* Mon May 29 2017 eatdirt <eatdirt> 1.26.1-1.mga6
+ Revision: 1105495
- Update to version 1.26.1

* Sun Dec 04 2016 daviddavid <daviddavid> 1.24-8.mga6
+ Revision: 1072095
- disable testsuite as xvfb-run fails again
- fix some dangling symlinks thus fixing desktop file icon not displayed in menu application
- use upstream desktop file and upstream mimetype file
- package the upstream appdata file
- use more new python macros

* Mon Jun 27 2016 akien <akien> 1.24-5.mga6
+ Revision: 1037871
- Rebuild again for updated PyQt4
- Rebuild in core/release

* Sat Jun 25 2016 akien <akien> 1.24-3.mga6
+ Revision: 1037524
- Rebuild for python-sip 4.18

* Sun May 22 2016 joequant <joequant> 1.24-2.mga6
+ Revision: 1017526
- bump
- upgrade to 1.24

* Tue Feb 09 2016 umeabot <umeabot> 1.18-12.mga6
+ Revision: 951854
- Mageia 6 Mass Rebuild

* Sat Nov 22 2014 alexl <alexl> 1.18-10.mga5
+ Revision: 798338
- translated desktop file (merged with OpenSuse and Debian)

  + umeabot <umeabot>
    - Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.18-8.mga5
+ Revision: 730702
- rebuild for missing pythoneggs deps

* Fri Sep 26 2014 tv <tv> 1.18-7.mga5
+ Revision: 725276
- rebuild for bogus file deps

* Tue Sep 16 2014 umeabot <umeabot> 1.18-6.mga5
+ Revision: 690199
- Mageia 5 Mass Rebuild

  + pterjan <pterjan>
    - Rebuild for new Python

* Wed Mar 19 2014 fwang <fwang> 1.18-4.mga5
+ Revision: 605485
- rebuild for new sip

* Tue Oct 22 2013 umeabot <umeabot> 1.18-3.mga4
+ Revision: 544609
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.18-2.mga4
+ Revision: 499970
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Aug 04 2013 joequant <joequant> 1.18-1.mga4
+ Revision: 463103
- update to 1.18

* Tue Jun 18 2013 joequant <joequant> 1.17.1-1.mga4
+ Revision: 444683
- fix typo
- imported package veusz

